BFGraph: preAllocMinHashIterator< HF > Class Template Reference

BFGraph

Public Member Functions | Data Fields
preAllocMinHashIterator< HF > Class Template Reference

## Public Member Functions
| preAllocMinHashIterator (const char *_s, int _n, int _k, int _g, HF _h, bool _nh)
bool | operator== (const preAllocMinHashIterator &o)
bool | operator!= (const preAllocMinHashIterator &o)
preAllocMinHashIterator & | operator++ ()
preAllocMinHashIterator | operator++ (int)
preAllocMinHashIterator & | operator+= (int i)
preAllocMinHashResultIterator< HF > | operator* () const
uint64_t | getHash () const
int | getPosition () const
int | getNbMin () const
int | getKmerPosition () const
minHashResult | getNewMin (const minHashResult &mhr_discard) const
| preAllocMinHashIterator (const preAllocMinHashIterator &o)
| preAllocMinHashIterator (const preAllocMinHashIterator &o, int len)

## Data Fields
const char * | s
int | n
int | k
int | g
HF | hf
vector< minHashResult > | v
size_t | p_cur_start
size_t | p_cur_end
int | p
bool | invalid
bool | nh

The documentation for this class was generated from the following file:

- src/minHashIterator.hpp